If you use **AIXD** in your work, please cite it as:

```
@misc{aixd,
  title = {{AIXD: AI-eXtended Design}},
  year = {2024},
  publisher = {Renku GitLab},
  howpublished = {\url{https://gitlab.renkulab.io/ai-augmented-design/aixd/}},
}
```